@@ -6,8 +6,8 @@ class NetcashGatewayAdmin(admin.ModelAdmin):
 
 class NetcashOrderAdmin(admin.ModelAdmin):
     list_display = ['Reference', 'created_at', 'updated_at', 'Amount',
-                    'Reason', 'RETC', 'request_ip', 'TransactionAccepted', 'suspicious']
-    list_filter = ['TransactionAccepted', 'suspicious']
+                    'Reason', 'RETC', 'request_ip', 'TransactionAccepted', 'trusted']
+    list_filter = ['TransactionAccepted', 'trusted']
     search_fields = ['Reference']
     date_hierarchy = 'created_at'
 
