@@ -34,7 +34,7 @@ def data_handler(request, secret):
         if ip != gateway.netcash_ip:
             order.request_ip = ip
             order.debug_info = 'untrusted ip: %s != %s' % (gateway.netcash_ip, ip)
-            order.suspicious = True
+            order.trusted = False
             order.save()
             raise Http404
 
@@ -44,14 +44,14 @@ def data_handler(request, secret):
         order.request_ip = ip
         order.gateway = gateway
         order.debug_info = request.raw_post_data
-        order.suspicious = False
+        order.trusted = True
         order.save()
         signals.data.send(sender = data_handler, order=order)
         return HttpResponse()
 
     errors = form.plain_errors()[:255]
     order.debug_info = errors
-    order.suspicious = True
+    order.trusted = False
     order.save()
     return HttpResponse(errors)
 
